@@ -15,14 +15,13 @@
  * @author Michael Goffioul
  */
 
-#ifndef KTNEFMESSAGE_H
-#define KTNEFMESSAGE_H
+#pragma once
 
 #include <QList>
 
-#include "ktnefpropertyset.h"
 #include "ktnef_export.h"
-
+#include "ktnefpropertyset.h"
+#include <memory>
 namespace KTnef
 {
 class KTNEFAttach;
@@ -30,7 +29,6 @@ class KTNEFAttach;
 
 namespace KTnef
 {
-
 /**
  * @brief
  * Represents a @acronym TNEF message.
@@ -78,16 +76,15 @@ public:
      * Returns the Rich Text Format (@acronym RTF) data contained in the message.
      * @return A QString containing the @acronym RTF data.
      */
-    Q_REQUIRED_RESULT QString rtfString() const;
+    [[nodiscard]] QString rtfString() const;
 
 private:
     //@cond PRIVATE
     class MessagePrivate;
-    MessagePrivate *const d;
+    std::unique_ptr<MessagePrivate> const d;
     //@endcond
 
     Q_DISABLE_COPY(KTNEFMessage)
 };
 
 }
-#endif
